@@ -7,6 +7,7 @@ import shutil
 import tarfile
 import zipfile
 import logging
+import filecmp
 import datetime
 import configparser
 from pathlib import Path
@@ -460,3 +461,28 @@ def save_ini_config_object(config_path: Path, _object: configparser.ConfigParser
     """保存配置文件到config.int中"""
     with open(config_path, mode="w", encoding="utf-8") as _file:
         _object.write(_file)
+
+
+def compare_dir(target1: str, target2: str) -> bool:
+    """比较两个目标是否完成一致"""
+    logger.info(f"开始比较目录：{target1}与{target2}")
+
+    def print_diff_files(dcmp):
+        for name in dcmp.diff_files:
+            logger.error("diff_file %s found in %s and %s" % (name, dcmp.left, dcmp.right))
+        for sub_dcmp in dcmp.subdirs.values():
+            print_diff_files(sub_dcmp)
+
+    cmp_res = filecmp.dircmp(target1, target2)
+    print_diff_files(cmp_res)
+    if cmp_res.diff_files:
+        logger.error("两个目录不完全相同")
+        return False
+    else:
+        logger.info("两个目录完全相同")
+        return True
+
+
+def compare_file(file1: str, file2: str) -> bool:
+    """比较两个文件是否一致"""
+    return filecmp.cmp(file1, file2, shallow=False)
