@@ -29,7 +29,7 @@ session = requests.Session()
 # session.headers.update(auth_header)
 
 
-def checkout_response(response: requests.Response):
+def checkout_response(response: requests.Response, level=""):
     """检查请求响应"""
     if response.status_code == 403 or response.status_code == 401:
         format_output(response, "error", depth=3)
@@ -38,7 +38,8 @@ def checkout_response(response: requests.Response):
     if response.status_code >= 400:
         format_output(response, "error", depth=3)
     else:
-        format_output(response, "debug", depth=3)
+        if level:
+            format_output(response, level=level, depth=3)
         return response.json()
 
 
@@ -134,7 +135,7 @@ def protection_branch(*, owner: str, repo: str, branch: str):
         "protected_file_patterns": "",
     }
     _res = session.post(_url, params=auth_params, json=payload)
-    return checkout_response(_res)
+    return checkout_response(_res, level="info")
 
 
 def cancel_protection_branch(*, owner: str, repo: str, branch: str):
@@ -158,7 +159,7 @@ def tetrieve_branch(*, owner: str, repo: str, branch: str):
     """检索特定分支"""
     _url = f"{DOMAIN}/repos/{owner}/{repo}/branches/{branch}"
     _res = session.get(_url, params=auth_params)
-    return checkout_response(_res)
+    return checkout_response(_res, level="debug")
 
 
 def create_branch(*, owner: str, repo: str, old_branch_name: str, new_branch_name: str):
@@ -195,7 +196,7 @@ def get_commit_default(*, owner: str, repo: str, sha: str):
     """获取commit详情"""
     _url = f"{DOMAIN}/repos/{owner}/{repo}/git/commits/{sha}"
     _res = session.get(_url, params=auth_params)
-    return checkout_response(_res)
+    return checkout_response(_res, level="debug")
 
 
 def release_exists(
@@ -227,7 +228,7 @@ def get_release_by_id(*, owner: str, repo: str, release_id: int):
     """获取release详情"""
     _url = f"{DOMAIN}/repos/{owner}/{repo}/releases/{release_id}"
     _res = session.get(_url, params=auth_params)
-    return checkout_response(_res)
+    return checkout_response(_res, level="debug")
 
 
 def create_release(*, owner: str, repo: str, payload: dict) -> dict:
@@ -249,7 +250,7 @@ def create_release(*, owner: str, repo: str, payload: dict) -> dict:
         f"【{owner}/{repo}】库发布版本，参数：{json.dumps(payload, ensure_ascii=False, indent=4)}"
     )
     _res = session.post(_url, params=auth_params, json=payload)
-    return checkout_response(_res)
+    return checkout_response(_res, level="info")
 
 
 def batch_delete_release(release_list: list):
@@ -274,7 +275,7 @@ def delete_release(*, owner: str, repo: str, release_id: int):
     logger.info(f"可删除性校验通过，开始删除release: {release_obj['name']}")
     _url = f"{DOMAIN}/repos/{owner}/{repo}/releases/{release_id}"
     _res = session.delete(_url, params=auth_params)
-    return checkout_response(_res)
+    return checkout_response(_res, level="info")
 
 
 def get_pulls(
@@ -324,7 +325,7 @@ def get_pull_by_issue_id(*, owner: str, repo: str, issue_id: int):
     """获取指定issue详情"""
     _url = f"{DOMAIN}/repos/{owner}/{repo}/pulls/{issue_id}"
     _res = session.get(_url, params=auth_params)
-    return checkout_response(_res)
+    return checkout_response(_res, level="debug")
 
 
 def merge_new(
@@ -357,7 +358,7 @@ def merge_new(
         _r = re.search(_e, _res.text, re.I)
         issue_id = int(_r.groups()[0])
         return get_pull_by_issue_id(owner=owner, repo=repo, issue_id=issue_id)
-    return checkout_response(_res)
+    return checkout_response(_res, level="debug")
 
 
 if __name__ == "__main__":
