@@ -5,38 +5,41 @@ import time
 import ctypes
 import logging
 from pathlib import Path
-
+from urllib.parse import urlparse
 from .utils import execute_cmd, byte_to_str, bytes_to_str, ExecuteCMDException
 
 
 logger = logging.getLogger("DengUtils")
-__system_path = Path(os.environ["TEMP"]) / "system_info.json"
 
 
-def get_system_info() -> dict:
+def get_system_info(win_rm_session=None) -> dict:
     """获取系统信息"""
-    _system_info: dict
-    if __system_path.exists():
-        with open(__system_path, encoding="utf-8") as _file:
-            try:
-                _system_info = json.load(_file)
-            except Exception as e:
-                logger.exception(e)
-                logger.warning(f"读取缓存出错，重新计算：{str(e)}")
-            else:
-                for _key, _value in _system_info.items():
-                    if not _value:
-                        logger.warning(f"缓存信息不完整，重新计算：{_system_info}")
-                        break
+    # 本地缓存路径
+    __system_path = Path(os.environ.get("TEMP") or os.environ.get("HOME")) / "system_info.json"
+    # 本地时优化检查缓存，远程不存在缓存一说
+    if not win_rm_session:
+        _system_info: dict
+        if __system_path.exists():
+            with open(__system_path, encoding="utf-8") as _file:
+                try:
+                    _system_info = json.load(_file)
+                except Exception as e:
+                    logger.exception(e)
+                    logger.warning(f"读取缓存出错，重新计算：{str(e)}")
                 else:
-                    timestamp = _system_info.pop("timestamp")
-                    if int(time.time()) - timestamp <= 1 * 24 * 60 * 60:
-                        logger.debug(
-                            f"系统信息缓存未过期：{json.dumps(_system_info, ensure_ascii=False, indent=4)}"
-                        )
-                        return _system_info
+                    for _key, _value in _system_info.items():
+                        if not _value:
+                            logger.warning(f"缓存信息不完整，重新计算：{_system_info}")
+                            break
                     else:
-                        logger.info(f"缓存过期，重新获取")
+                        timestamp = _system_info.pop("timestamp")
+                        if int(time.time()) - timestamp <= 1 * 24 * 60 * 60:
+                            logger.debug(
+                                f"系统信息缓存未过期：{json.dumps(_system_info, ensure_ascii=False, indent=4)}"
+                            )
+                            return _system_info
+                        else:
+                            logger.info(f"缓存过期，重新获取")
 
     # 实时获取系统信息
     systems = {
@@ -48,8 +51,12 @@ def get_system_info() -> dict:
         "mac_address": "",
     }
     try:
-        res = execute_cmd(["systemInfo"], encoding=None, level=None)
-        system_info = bytes_to_str(res.stdout)
+        if win_rm_session:
+            res = win_rm_session.run_cmd("systemInfo")
+            system_info = bytes_to_str(res.std_out)
+        else:
+            res = execute_cmd(["systemInfo"], encoding=None, level=None)
+            system_info = bytes_to_str(res.stdout)
         for line in system_info.split("\n"):
             line = line.strip()
             if (
@@ -80,25 +87,36 @@ def get_system_info() -> dict:
             from . import net as net_utils
         except ImportError:
             import net as net_utils
-        systems["ip_address"] = net_utils.get_host_ip()
-        systems["mac_address"] = get_mac_address(systems["ip_address"])
+        if win_rm_session:
+            systems["ip_address"] = urlparse(win_rm_session.url).netloc.split(":")[0]
+        else:
+            systems["ip_address"] = net_utils.get_host_ip()
+        systems["mac_address"] = get_mac_address(systems["ip_address"], win_rm_session)
         logger.info(f"当前机器系统信息：{json.dumps(systems, ensure_ascii=False, indent=4)}")
-        with open(__system_path, mode="w", encoding="utf-8") as _file:
-            _temp = systems
-            _temp["timestamp"] = int(time.time())
-            json.dump(_temp, _file, ensure_ascii=False, indent=4)
+        if not win_rm_session:
+            with open(__system_path, mode="w", encoding="utf-8") as _file:
+                _temp = systems
+                _temp["timestamp"] = int(time.time())
+                json.dump(_temp, _file, ensure_ascii=False, indent=4)
         return systems
     except Exception as e:
         logger.exception(e)
         return systems
 
 
-def get_mac_address(ip_address: str) -> str:
-    """根据IP地址获取网卡MAC地址，兼容中文简体、中文繁体、英文"""
+def get_mac_address(ip_address: str, win_rm_session=None) -> str:
+    """根据IP地址获取网卡MAC地址，兼容中文简体、中文繁体、英文
+    :param ip_address: str, 目标网卡对应的IP地址
+    :param win_rm_session: Windows 远程管理服务会话对象
+    """
     mac_address: str = ""
     try:
-        res = execute_cmd(["ipconfig", "/all"], encoding=None, level=None)
-        network_info = bytes_to_str(res.stdout)
+        if win_rm_session:
+            res = win_rm_session.run_cmd("ipconfig /all")
+            network_info = bytes_to_str(res.std_out)
+        else:
+            res = execute_cmd(["ipconfig", "/all"], encoding=None, level=None)
+            network_info = bytes_to_str(res.stdout)
         for _line in network_info.split("\n"):
             _line = _line.strip()
             if _line:
@@ -132,14 +150,18 @@ def is_running_as_admin() -> bool:
         return False
 
 
-def get_current_app_list(detail=False) -> list:
+def get_current_app_list(detail=False, win_rm_session=None) -> list:
     """获取当前用户实时app列表"""
     cmd_text = 'tasklist /nh /fo csv /fi "SESSION ne 0"'
     if detail:
         cmd_text += " /v"
 
-    _res = execute_cmd(cmd_text, encoding=None, level=None)
-    out_decode = bytes_to_str(_res.stdout)
+    if win_rm_session:
+        _res = win_rm_session.run_cmd(cmd_text)
+        out_decode = bytes_to_str(_res.std_out)
+    else:
+        _res = execute_cmd(cmd_text, encoding=None, level=None)
+        out_decode = bytes_to_str(_res.stdout)
 
     _app_list = []
     for _line in out_decode.strip().split("\n"):
@@ -211,7 +233,3 @@ def get_exe_name_by_pid(pid: int) -> str:
 def is_32_python_on_window() -> bool:
     """判断当前是否为32位的Python"""
     return "32 bit" in sys.version
-
-
-if __name__ == "__main__":
-    print(get_system_info())
